use Test::More tests => 5;
use strict;
use DE_EPAGES::Core::API::Script qw (RunScript);
use DE_EPAGES::Database::API::Connection qw (ConnectTestSite DisconnectSite);
use DE_EPAGES::Object::API::Factory qw (GetRootObjectID LoadClassByAlias LoadRootObject);
use DE_EPAGES::Search::API::SearchTerm qw( RegisterTerm );
use DE_EPAGES::Trigger::DAL::Hook qw ( DAL_GetTriggerFunctions );

RunScript( 'Sub'=> sub {
    ConnectTestSite();

    ok(Init(), 'initialize');

    # Workaround for EPG-12289: load hooks outside of lockTables()
    DAL_GetTriggerFunctions('OBJ_InsertSearchTerm');

    my $Site = LoadRootObject();
    RegisterTerm( $Site, 'World', 7 );
    RegisterTerm( $Site, 'Hallo', 3 );
    RegisterTerm( $Site, 'HALLO', 4 );

    my $aSearchTerms = $Site->get('SearchTerms');
    is( scalar @$aSearchTerms, 2, "number of distinct search terms" );

    my %SearchTerms = map { $_->get('Term') => $_ } @$aSearchTerms;

    my $SearchTerm = $SearchTerms{'hallo'};
    is( $SearchTerm->get('CountResults'), 4, 'Most recent result count' );
    is( $SearchTerm->get('CountRequests'), 2, 'Number of requests' );

    ok(Cleanup(), "Cleanup");

    DisconnectSite();
});

sub Cleanup {

    LoadClassByAlias('SearchTerm')->deleteObjects('BySiteID', [GetRootObjectID()]);
    return 1;
}

sub Init {
    Cleanup();
    return 1;
}

1;
